@@ -28,13 +28,8 @@ def make_toolbar(main):
         (_('Fullscreen'), main._fullscreen, 'fullscreen16.png'),
         ]
 
-    styles = {'text': gtk.TOOLBAR_TEXT,
-              'icons': gtk.TOOLBAR_ICONS,
-              'both': gtk.TOOLBAR_BOTH}
     toolbar = gtk.Toolbar()
     toolbar.set_orientation(gtk.ORIENTATION_HORIZONTAL)
-    style = uihelpers.get_option(main.config, 'gtk.toolbar_style', 'both')
-    toolbar.set_style(styles.get(style, styles['both']))
     for index, item in enumerate(toolbar_buttons):
         if not item:
             toolbar.insert(gtk.SeparatorToolItem(), index)
@@ -46,3 +41,4 @@ def make_toolbar(main):
         button.connect('clicked', item[1])
         toolbar.insert(button, index)
     return toolbar
+
